@@ -94,7 +94,10 @@ sub AUTOLOAD {
   return if $method eq 'DESTROY';
   STDERR->print("RequestHolder AUTOLOAD: method: ``$method'' ( @_ )\n");
   my $self = shift;
-  my $retval = eval { $self->{request}->can($method)->($self->{request}, @_) };
+  my $retval = eval { 
+      $self->{request}->can($method) or die "request object doesn't implemented requested method\n"; 
+      $self->{request}->can($method)->($self->{request}, @_); 
+  };
   if($@) {
     warn "Continuity::::RequestHolder::AUTOLOAD: Error delegating method ``$method'': $@";
   }
